@@ -2,6 +2,7 @@
  *  This file is part of nzbget. See <https://nzbget.com>.
  *
  *  Copyright (C) 2013-2016 Andrey Prygunkov <hugbug@users.sourceforge.net>
+ *  Copyright (C) 2025 Denis <denis@nzbget.com>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -14,14 +15,14 @@
  *  GNU General Public License for more details.
  *
  *  You should have received a copy of the GNU General Public License
- *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *  along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 
 #ifndef FEEDINFO_H
 #define FEEDINFO_H
 
-#include "NString.h"
+#include <string>
 #include "Util.h"
 #include "DownloadInfo.h"
 
@@ -36,19 +37,28 @@ public:
 		fsFailed
 	};
 
-	FeedInfo(int id, const char* name, const char* url, bool backlog, int interval,
-		const char* filter, bool pauseNzb, const char* category, int priority,
-		const char* extensions);
+	FeedInfo(
+		int id,
+		const char* name,
+		const char* url,
+		bool backlog,
+		int interval,
+		const char* filter,
+		bool pauseNzb,
+		const char* category,
+		int priority,
+		const char* extensions
+	);
 	int GetId() { return m_id; }
-	const char* GetName() { return m_name; }
-	const char* GetUrl() { return m_url; }
+	const char* GetName() const { return m_name.c_str(); }
+	const char* GetUrl() const { return m_url.c_str(); }
 	int GetInterval() { return m_interval; }
-	const char* GetFilter() { return m_filter; }
+	const char* GetFilter() const { return m_filter.c_str(); }
 	uint32 GetFilterHash() { return m_filterHash; }
 	bool GetPauseNzb() { return m_pauseNzb; }
-	const char* GetCategory() { return m_category; }
+	const char* GetCategory() const { return m_category.c_str(); }
 	int GetPriority() { return m_priority; }
-	const char* GetExtensions() { return m_extensions; }
+	const char* GetExtensions() const { return m_extensions.c_str(); }
 	time_t GetLastUpdate() { return m_lastUpdate; }
 	void SetLastUpdate(time_t lastUpdate) { m_lastUpdate = lastUpdate; }
 	time_t GetNextUpdate() { return m_nextUpdate; }
@@ -59,8 +69,8 @@ public:
 	void SetPreview(bool preview) { m_preview = preview; }
 	EStatus GetStatus() { return m_status; }
 	void SetStatus(EStatus Status) { m_status = Status; }
-	const char* GetOutputFilename() { return m_outputFilename; }
-	void SetOutputFilename(const char* outputFilename) { m_outputFilename = outputFilename; }
+	const char* GetOutputFilename() const { return m_outputFilename.c_str(); }
+	void SetOutputFilename(const char* outputFilename) { m_outputFilename = outputFilename ? outputFilename : ""; }
 	bool GetFetch() { return m_fetch; }
 	void SetFetch(bool fetch) { m_fetch = fetch; }
 	bool GetForce() { return m_force; }
@@ -70,22 +80,22 @@ public:
 
 private:
 	int m_id;
-	CString m_name;
-	CString m_url;
-	bool m_backlog;
-	int m_interval;
-	CString m_filter;
-	uint32 m_filterHash;
-	bool m_pauseNzb;
-	CString m_category;
-	CString m_extensions;
-	int m_priority;
+	std::string m_name;
+	std::string m_url;
+	std::string m_category;
+	std::string m_extensions;
+	std::string m_filter;
+	std::string m_outputFilename;
 	time_t m_lastUpdate = 0;
 	time_t m_nextUpdate = 0;
-	int m_lastInterval = 0;
-	bool m_preview = false;
+	uint32 m_filterHash;
 	EStatus m_status = fsUndefined;
-	CString m_outputFilename;
+	int m_interval;
+	int m_priority;
+	int m_lastInterval = 0;
+	bool m_backlog;
+	bool m_pauseNzb;
+	bool m_preview = false;
 	bool m_fetch = false;
 	bool m_force = false;
 };
@@ -120,13 +130,15 @@ public:
 	class Attr
 	{
 	public:
-		Attr(const char* name, const char* value) :
-			m_name(name ? name : ""), m_value(value ? value : "") {}
-		const char* GetName() { return m_name; }
-		const char* GetValue() { return m_value; }
+		Attr(const char* name, const char* value)
+			: m_name(name ? name : "")
+			, m_value(value ? value : "") 
+		{ }
+		const char* GetName() const { return m_name.c_str(); }
+		const char* GetValue() const { return m_value.c_str(); }
 	private:
-		CString m_name;
-		CString m_value;
+		std::string m_name;
+		std::string m_value;
 	};
 
 	typedef std::deque<Attr> AttributesBase;
@@ -140,16 +152,16 @@ public:
 	FeedItemInfo() {}
 	FeedItemInfo(FeedItemInfo&&) = delete; // catch performance issues
 	void SetFeedFilterHelper(FeedFilterHelper* feedFilterHelper) { m_feedFilterHelper = feedFilterHelper; }
-	const char* GetTitle() { return m_title; }
-	void SetTitle(const char* title) { m_title = title; }
-	const char* GetFilename() { return m_filename; }
-	void SetFilename(const char* filename) { m_filename = filename; }
-	const char* GetUrl() { return m_url; }
-	void SetUrl(const char* url) { m_url = url; }
+	const char* GetTitle() const { return m_title.c_str(); }
+	void SetTitle(const char* title) { m_title = title ? title : ""; }
+	const char* GetFilename() const { return m_filename.c_str(); }
+	void SetFilename(const char* filename) { m_filename = filename ? filename : ""; }
+	const char* GetUrl() const { return m_url.c_str(); }
+	void SetUrl(const char* url) { m_url = url ? url : ""; }
 	int64 GetSize() { return m_size; }
 	void SetSize(int64 size) { m_size = size; }
-	const char* GetCategory() { return m_category; }
-	void SetCategory(const char* category) { m_category = category; }
+	const char* GetCategory() const { return m_category.c_str(); }
+	void SetCategory(const char* category) { m_category = category ? category : ""; }
 	int GetImdbId() { return m_imdbId; }
 	void SetImdbId(int imdbId) { m_imdbId = imdbId; }
 	int GetRageId() { return m_rageId; }
@@ -158,15 +170,15 @@ public:
 	void SetTvdbId(int tvdbId) { m_tvdbId = tvdbId; }
 	int GetTvmazeId() { return m_tvmazeId; }
 	void SetTvmazeId(int tvmazeId) { m_tvmazeId = tvmazeId; }
-	const char* GetDescription() { return m_description; }
+	const char* GetDescription() const { return m_description.c_str(); }
 	void SetDescription(const char* description) { m_description = description ? description: ""; }
-	const char* GetSeason() { return m_season; }
+	const char* GetSeason() const { return m_season.c_str(); }
 	void SetSeason(const char* season);
-	const char* GetEpisode() { return m_episode; }
+	const char* GetEpisode() const { return m_episode.c_str(); }
 	void SetEpisode(const char* episode);
 	int GetSeasonNum();
 	int GetEpisodeNum();
-	const char* GetAddCategory() { return m_addCategory; }
+	const char* GetAddCategory() const { return m_addCategory.c_str(); }
 	void SetAddCategory(const char* addCategory) { m_addCategory = addCategory ? addCategory : ""; }
 	bool GetPauseNzb() { return m_pauseNzb; }
 	void SetPauseNzb(bool pauseNzb) { m_pauseNzb = pauseNzb; }
@@ -180,7 +192,7 @@ public:
 	void SetMatchStatus(EMatchStatus matchStatus) { m_matchStatus = matchStatus; }
 	int GetMatchRule() { return m_matchRule; }
 	void SetMatchRule(int matchRule) { m_matchRule = matchRule; }
-	const char* GetDupeKey() { return m_dupeKey; }
+	const char* GetDupeKey() const { return m_dupeKey.c_str(); }
 	void SetDupeKey(const char* dupeKey) { m_dupeKey = dupeKey ? dupeKey : ""; }
 	void AppendDupeKey(const char* extraDupeKey);
 	void BuildDupeKey(const char* rageId, const char* tvdbId, const char* tvmazeId, const char* series);
@@ -192,32 +204,32 @@ public:
 	Attributes* GetAttributes() { return &m_attributes; }
 
 private:
-	CString m_title;
-	CString m_filename;
-	CString m_url;
+	std::string m_title;
+	std::string m_filename;
+	std::string m_url;
+	std::string m_category;
+	std::string m_description;
+	std::string m_season;
+	std::string m_episode;
+	std::string m_addCategory;
+	std::string m_dupeKey;
+	std::string m_dupeStatus;
 	time_t m_time = 0;
 	int64 m_size = 0;
-	CString m_category = "";
 	int m_imdbId = 0;
 	int m_rageId = 0;
 	int m_tvdbId = 0;
 	int m_tvmazeId = 0;
-	CString m_description = "";
-	CString m_season;
-	CString m_episode;
 	int m_seasonNum = 0;
 	int m_episodeNum = 0;
 	bool m_seasonEpisodeParsed = false;
-	CString m_addCategory = "";
 	bool m_pauseNzb = false;
 	int m_priority = 0;
 	EStatus m_status = isUnknown;
 	EMatchStatus m_matchStatus = msIgnored;
 	int m_matchRule = 0;
-	CString m_dupeKey;
 	int m_dupeScore = 0;
 	EDupeMode m_dupeMode = dmScore;
-	CString m_dupeStatus;
 	FeedFilterHelper* m_feedFilterHelper = nullptr;
 	Attributes m_attributes;
 
@@ -237,16 +249,18 @@ public:
 		hsFetched
 	};
 
-	FeedHistoryInfo(const char* url, EStatus status, time_t lastSeen) :
-		m_url(url), m_status(status), m_lastSeen(lastSeen) {}
-	const char* GetUrl() { return m_url; }
+	FeedHistoryInfo(const char* url, EStatus status, time_t lastSeen) 
+		: m_url{ url ? url : "" }
+		, m_status{ status }
+		, m_lastSeen{ lastSeen } {}
+	const char* GetUrl() const { return m_url.c_str(); }
 	EStatus GetStatus() { return m_status; }
 	void SetStatus(EStatus Status) { m_status = Status; }
 	time_t GetLastSeen() { return m_lastSeen; }
 	void SetLastSeen(time_t lastSeen) { m_lastSeen = lastSeen; }
 
 private:
-	CString m_url;
+	std::string m_url;
 	EStatus m_status;
 	time_t m_lastSeen;
 };
