@@ -1,8 +1,8 @@
 /*
- *  This file is part of nzbget. See <http://nzbget.net>.
+ *  This file is part of nzbget. See <https://nzbget.com>.
  *
  *  Copyright (C) 2005 Bo Cordes Petersen <placebodk@sourceforge.net>
- *  Copyright (C) 2007-2016 Andrey Prygunkov <hugbug@users.sourceforge.net>
+ *  Copyright (C) 2007-2019 Andrey Prygunkov <hugbug@users.sourceforge.net>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -23,12 +23,14 @@
 #include "BinRpc.h"
 #include "Log.h"
 #include "Options.h"
+#include "WorkState.h"
 #include "QueueEditor.h"
 #include "Util.h"
 #include "FileSystem.h"
 #include "DownloadInfo.h"
 #include "Scanner.h"
 #include "StatMeter.h"
+#include "UrlCoordinator.h"
 
 extern void ExitProc();
 extern void Reload();
@@ -312,20 +314,20 @@ void PauseUnpauseBinCommand::Execute()
 		return;
 	}
 
-	g_Options->SetResumeTime(0);
+	g_WorkState->SetResumeTime(0);
 
 	switch (ntohl(PauseUnpauseRequest.m_action))
 	{
 		case rpDownload:
-			g_Options->SetPauseDownload(ntohl(PauseUnpauseRequest.m_pause));
+			g_WorkState->SetPauseDownload(ntohl(PauseUnpauseRequest.m_pause));
 			break;
 
 		case rpPostProcess:
-			g_Options->SetPausePostProcess(ntohl(PauseUnpauseRequest.m_pause));
+			g_WorkState->SetPausePostProcess(ntohl(PauseUnpauseRequest.m_pause));
 			break;
 
 		case rpScan:
-			g_Options->SetPauseScan(ntohl(PauseUnpauseRequest.m_pause));
+			g_WorkState->SetPauseScan(ntohl(PauseUnpauseRequest.m_pause));
 			break;
 	}
 
@@ -340,7 +342,7 @@ void SetDownloadRateBinCommand::Execute()
 		return;
 	}
 
-	g_Options->SetDownloadRate(ntohl(SetDownloadRequest.m_downloadRate));
+	g_WorkState->SetSpeedLimit(ntohl(SetDownloadRequest.m_downloadRate));
 	SendBoolResponse(true, "Rate-Command completed successfully");
 }
 
@@ -430,9 +432,7 @@ void DownloadBinCommand::Execute()
 		nzbInfo->SetDupeScore(dupeScore);
 		nzbInfo->SetDupeMode((EDupeMode)dupeMode);
 
-		GuardedDownloadQueue downloadQueue = DownloadQueue::Guard();
-		downloadQueue->GetQueue()->Add(std::move(nzbInfo), addTop);
-		downloadQueue->Save();
+		g_UrlCoordinator->AddUrlToQueue(std::move(nzbInfo), addTop);
 
 		ok = true;
 	}
@@ -671,14 +671,15 @@ void ListBinCommand::Execute()
 		}
 
 		uint32 sizeHi, sizeLo;
-		ListResponse.m_downloadRate = htonl(g_StatMeter->CalcCurrentDownloadSpeed());
+		uint32 downloadRate = Util::SafeIntCast<int64, uint32>(g_StatMeter->CalcCurrentDownloadSpeed());
+		ListResponse.m_downloadRate = htonl(downloadRate);
 		Util::SplitInt64(remainingSize, &sizeHi, &sizeLo);
 		ListResponse.m_remainingSizeHi = htonl(sizeHi);
 		ListResponse.m_remainingSizeLo = htonl(sizeLo);
-		ListResponse.m_downloadLimit = htonl(g_Options->GetDownloadRate());
-		ListResponse.m_downloadPaused = htonl(g_Options->GetPauseDownload());
-		ListResponse.m_postPaused = htonl(g_Options->GetPausePostProcess());
-		ListResponse.m_scanPaused = htonl(g_Options->GetPauseScan());
+		ListResponse.m_downloadLimit = htonl(g_WorkState->GetSpeedLimit());
+		ListResponse.m_downloadPaused = htonl(g_WorkState->GetPauseDownload());
+		ListResponse.m_postPaused = htonl(g_WorkState->GetPausePostProcess());
+		ListResponse.m_scanPaused = htonl(g_WorkState->GetPauseScan());
 		ListResponse.m_threadCount = htonl(Thread::GetThreadCount() - 1); // not counting itself
 		ListResponse.m_postJobCount = htonl(postJobCount);
 
@@ -871,7 +872,7 @@ void EditQueueBinCommand::Execute()
 	else
 	{
 #ifndef HAVE_REGEX_H
-		if ((QueueEditor::EMatchMode)matchMode == QueueEditor::mmRegEx)
+		if ((DownloadQueue::EMatchMode)matchMode == DownloadQueue::mmRegEx)
 		{
 			SendBoolResponse(false, "Edit-Command failed: the program was compiled without RegEx-support");
 			return;
